# -*- coding: utf-8 -*-
# @Time         : 2018/11/26 下午7:52
# @Author       : luoyeqi
# @Email        : luoyeqi@duoshoubang.cn
# @FileName     : __init__.py
# @Description  :

from dirtreegen.dirtreegen import treegen

name = 'dirtreegen'
treegen = treegen